/*       ͻ
             TITLE:  HDLC State machine routines for Keil C        
          FILENAME:  HDLC.h                                        
          REVISION:  VER 0.0                                       
          REV.DATE:  13-12-04                                      
           ARCHIVE:                                                
            AUTHOR:  Copyright (c) 2004, Murray R.Van Luyn.        
         ͼ        */


#ifndef HDLC_H
#define HDLC_H

#include "t89c51ac2.h"
#include <stdlib.h>    // malloc(), free()

/*  ͻ
                            Publicly Defined Constants                   
    ͼ  */
// RX State Machine states
#define RX_IDLE              0
#define RX_SYNCHRONISED      1
#define RX_RECEIVING         2

// RX Buffer defines
// Use unsigned int for all 3 rx_buffer indexes when RX_BUFFER_LEN > 255
#define RX_BUFFER_LEN      255        // (2^n)-1 as a circular buffer
#define RX_MAX_PACKET_LEN  127        // Largest packet accepted

// TX State Machine states
#define TX_PREAMBLE_0        3
#define TX_PREAMBLE_1        4
#define TX_TRANSMITTING      5
#define TX_INTER_SYNC_0      6
#define TX_INTER_SYNC_1      7
#define TX_INTER_SYNC_2      8

// TX Buffer defines
// Use unsigned int for all 3 tx_buffer indexes when TX_BUFFER_LEN > 255
#define TX_BUFFER_LEN      255        // (2^n)-1 as a circular buffer
#define TX_MAX_PACKET_LEN  127        // Largest packet accepted

// X1 mode timing parameters
#define XTAL                 18432000              // Hz
#define CPU_CLOCK            XTAL / 12             // X1 mode
#define PCA_CLOCK            XTAL / 12             // PCA mode 1
#define HDLC_BPS             1200                  // Tranceiver baud rate
#define PCA_1_BIT_COUNT      PCA_CLOCK / HDLC_BPS
#define PCA_8_BIT_COUNT      PCA_1_BIT_COUNT * 8   

// Transmission parameters
#define TX_PREAMBLE_LEN      3        // Number of SYNC before data
#define TX_DWAIT             3        // Clear channel delay before tx
                                      // in 6.66ms increments
#define TX_DELAY             0        // Delay before SYNC after keyup
#define TX_TAIL              0        // Delay before keydown after data
#define TX_PORT_PIN       P1_4        // Transmission output pin CEX1 P1.4
#define RX_PORT_PIN       P1_3        // Reception input pin CEX1 P1.3


/*  ͻ
                             Public Global Variables                     
    ͼ  */


/*  ͻ
                            Public Function Prototypes                   
    ͼ  */
extern void hdlc_init_pca(void);
extern bit tx_send_packet(unsigned char * packet);

// HDLC module expects to find this in upper layers
extern void hdlc_upcall(unsigned char xdata *packet_ptr);
#endif
