/*       ͻ
             TITLE:  AT89C51AC2 SIO routines for Keil C Compiler   
          FILENAME:  Sio_poll.c                                    
          REVISION:  VER 0.1                                       
          REV.DATE:  15-12-04                                      
           ARCHIVE:                                                
            AUTHOR:  Copyright (c) 2004, Murray R.Van Luyn.        
         ͼ        */


#include "Sio_poll.h"

/*  ͻ
                           Private Function Prototypes                   
    ͼ  */



/*  ͻ
                         Public Function Implementation                  
    ͼ  */

/*  ͻ
                                                                         
                               init_sio_out()                            
                                                                         
                     Initialise SIO for 9600 8N1 operation               
                                                                         
    ͼ  */
void init_sio_poll(void)
{
    TR1  = 0;                 // Stop Timer 1 from running
    IEN0 &= 0xF7;             // Disable Timer 1 interrupt
    TMOD &= 0x0F;             // set up timer/counter 1 to drive 9600 baudrate
    TMOD |= 0x20;             // timer/counter 1 is set for mode 2 8-bit TIMER
    TH1  = 0xFB;              // timer/counter 1 is timed for 9600 baud
    TR1  = 1;                 // timer/counter 1 is enabled and will free run
    SCON = 0x50;              // Set port 1 for mode 1: 8N1 operation
    TI   = 1;                 // Set TI to indicate TX buffer empty

    return;
}


/*  ͻ
                                                                         
                                 putchar()                               
                                                                         
                                                                         
    ͼ  */
char putchar(char outChar)
{

    while(!TI);               // Wait till last character sent
    TI = 0;                   // Clear TI to indicate TX buffer full
    SBUF = outChar;           // Next character to send into sio

    return outChar;
}


/*  ͻ
                                                                         
                                 _getkey()                               
                                                                         
                                                                         
    ͼ  */
char _getkey(void)
{
    char inChar;

    while(!RI);               // Wait until a character received
    inChar = SBUF;            // Read input character
    RI = 0;                      // Clear RI to indicate reception

    return inChar;
}
